@@ -1,27 +1,26 @@
 import functools
-import joblib
+import heflow.contexts
 import numpy
-import os
 import tenseal
 
 
 class CKKSTensor:
-    context = tenseal.context_from(
-        joblib.load(os.getenv('HEFLOW_CKKS', 'id_ckks')))
+    key = heflow.contexts.ckks_context().key()
 
     def __getstate__(self):
         return {'data': self.backend.serialize()}
 
     @functools.singledispatchmethod
     def __init__(self, data):
-        self.backend = tenseal.ckks_tensor(self.context, data)
+        self.backend = tenseal.ckks_tensor(self.key.backend, data)
 
     @__init__.register
     def _(self, backend: tenseal.CKKSTensor):
         self.backend = backend
 
     def __setstate__(self, state):
-        self.backend = tenseal.ckks_tensor_from(self.context, state['data'])
+        self.backend = tenseal.ckks_tensor_from(self.key.backend,
+                                                state['data'])
 
     def add(self, other):
         if isinstance(other, CKKSTensor):
